summaryrefslogtreecommitdiffhomepage
path: root/src/raylib.h
diff options
context:
space:
mode:
authorraysan5 <[email protected]>2020-09-18 13:50:51 +0200
committerraysan5 <[email protected]>2020-09-18 13:50:51 +0200
commit152665ff48be90f571888a5aaed1bbb29b6cb33e (patch)
tree5c1b2f1c8ad3414115fa3e7de9b2fcaa8ae68b25 /src/raylib.h
parentb7867fb10d6b6ec6bff80009d3d8413c11fad80a (diff)
downloadraylib-152665ff48be90f571888a5aaed1bbb29b6cb33e.tar.gz
raylib-152665ff48be90f571888a5aaed1bbb29b6cb33e.zip
REDESIGNED: GenTexture*() #721
Functions have been redesigned to use rlgl and allow to externalize them (aka removing them from rlgl because they use custom shaders...).
Diffstat (limited to 'src/raylib.h')
-rw-r--r--src/raylib.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/raylib.h b/src/raylib.h
index 73d75429..e76bdb5b 100644
--- a/src/raylib.h
+++ b/src/raylib.h
@@ -1382,9 +1382,9 @@ RLAPI Matrix GetMatrixProjection(void); // Get
// Texture maps generation (PBR)
// NOTE: Required shaders should be provided
-RLAPI Texture2D GenTextureCubemap(Shader shader, Texture2D map, int size); // Generate cubemap texture from 2D texture
-RLAPI Texture2D GenTextureIrradiance(Shader shader, Texture2D cubemap, int size); // Generate irradiance texture using cubemap data
-RLAPI Texture2D GenTexturePrefilter(Shader shader, Texture2D cubemap, int size); // Generate prefilter texture using cubemap data
+RLAPI TextureCubemap GenTextureCubemap(Shader shader, Texture2D panorama, int size); // Generate cubemap texture from 2D panorama texture
+RLAPI TextureCubemap GenTextureIrradiance(Shader shader, TextureCubemap cubemap, int size); // Generate irradiance texture using cubemap data
+RLAPI TextureCubemap GenTexturePrefilter(Shader shader, TextureCubemap cubemap, int size); // Generate prefilter texture using cubemap data
RLAPI Texture2D GenTextureBRDF(Shader shader, int size); // Generate BRDF texture
// Shading begin/end functions